@@ -1,12 +1,12 @@
 from typing import Optional
 
 import typer
-from dotenv import load_dotenv
 
-from .commands import find
-from .utils.version import get_version
+from cli.commands import find
+from cli.utils import get_version
+from cli.settings import load_settings
 
-load_dotenv()
+settings = load_settings()
 
 app = typer.Typer(add_completion=False)
 app.add_typer(find.app, name="find")
